@@ -1,6 +1,6 @@
 package Tie::Hash::DBD;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use strict;
 use warnings;
@@ -60,6 +60,12 @@ my %DB = (
 	t_val	=> "text",
 	clear	=> "delete from",
 	},
+    Firebird	=> {
+	temp	=> "",
+	t_key	=> "varchar (8192)",
+	t_val	=> "varchar (8192)",
+	clear	=> "delete from",
+	},
     );
 
 sub _create_table
@@ -105,7 +111,7 @@ sub TIEHASH
 	    RaiseError       => 1,
 	    PrintWarn        => 0,
 	    FetchHashKeyName => "NAME_lc",
-	    }) or croak DBI->errstr;
+	    }) or croak (DBI->errstr);
 
     my $dbt = $dbh->{Driver}{Name} || "no DBI handle";
     my $cnf = $DB{$dbt} or croak "I don't support database '$dbt'";
@@ -314,7 +320,7 @@ __END__
 
 =head1 NAME
 
-Tie::Hash::DBD, tie a plain hash to a database table
+Tie::Hash::DBD - tie a plain hash to a database table
 
 =head1 SYNOPSIS
 
@@ -370,7 +376,8 @@ all by itself, but uses the connection provided in the handle.
 If the first argument is a scalar, it is used as DSN for DBI->connect ().
 
 Supported DBD drivers include DBD::Pg, DBD::SQLite, DBD::CSV, DBD::mysql,
-DBD::Oracle, and DBD::Unify.
+DBD::Oracle, DBD::Unify, and DBD::Firebird.  Note that due to limitations
+they won't all perform equally well.
 
 DBD::Pg and DBD::SQLite have an unexpected great performance when server
 is the local system. DBD::SQLite is even almost as fast as DB_File.
@@ -495,6 +502,13 @@ approaches that enable you to fit in your own.
 
 Note that neither DBD::CSV nor DBD::Unify support C<AutoCommit>.
 
+=item *
+
+For now, Firebird does not support C<TEXT> (or C<CLOB>) in DBD::Firebird
+at a level required by Tie::Hash::DBD. Neither does it support arbitrary
+length index on C<VARCHAR> fields so it can neither be a primary key nor
+can it be the subject of a (unique) index, hence large sets will be slow
+
 =back
 
 =head1 TODO
@@ -519,14 +533,14 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2011 H.Merijn Brand
+Copyright (C) 2010-2014 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
-DBI, Tie::DBI, Tie::Hash, Redis::Hash
+DBI, Tie::DBI, Tie::Hash, Tie::Array::DBD, Redis::Hash
 
 =cut
 
